@@ -3,15 +3,17 @@ import tkinter.font as tkFont
 import tkinter.ttk as ttk
 import tkinter.scrolledtext as ts 
 import tkinter.messagebox as mb
+import os
+
 
 
 class Layout(tk.Tk):
     def __init__(self):
 
         super().__init__()
-
+        print(os.getcwd)
         self.__title = "carrot app"
-        self.__icon = "carrot-icon.ico"
+        self.__icon = "./carrot-icon.ico"
         self.__width = int(self.winfo_screenwidth())
         self.__height = int(self.winfo_screenheight())
         self.__close_message = "Kill carrot?"
